@@ -1,8 +1,15 @@
 use crate::security::*;
+
+#[cfg(feature="extended-handler")]
 use crate::types::application::*;
+
+#[cfg(feature="handler")]
 use crate::types::interaction::*;
+
+#[cfg(feature="extended-handler")]
 use crate::types::HttpError;
 use crate::types::Snowflake;
+#[cfg(feature="extended-handler")]
 use crate::{expect_specific_api_response, expect_successful_api_response_and_return};
 use actix_web::http::StatusCode;
 use actix_web::{web, App, HttpRequest, HttpResponse, HttpServer, Result};
@@ -50,16 +57,17 @@ macro_rules! match_handler_response {
     };
 }
 
+#[cfg(feature = "handler")]
 #[non_exhaustive]
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
-/// Used for some functions to define which scope should be manipulated. 
-pub enum ManipulationScope{
+/// Used for some functions to define which scope should be manipulated.
+pub enum ManipulationScope {
     /// Only apply changes locally
     Local,
     /// Apply changes locally and to Discord
     All,
     /// Only apply changes with Discord
-    Discord
+    Discord,
 }
 
 #[cfg(feature = "handler")]
@@ -98,25 +106,34 @@ impl InteractionHandler {
     /// Initalizes a new `InteractionHandler`
     pub fn new(
         app_id: Snowflake,
-        pbk_str: &str,
-        token: Option<&'static str>,
+        pbk_str: impl AsRef<str>,
+        token: Option<&String>,
     ) -> InteractionHandler {
         let pbk_bytes =
-            hex::decode(pbk_str).expect("Failed to parse the public key from hexadecimal");
+            hex::decode(pbk_str.as_ref()).expect("Failed to parse the public key from hexadecimal");
 
         let app_public_key =
             PublicKey::from_bytes(&pbk_bytes).expect("Failed to parse public key.");
 
         if let Some(token) = token {
             let mut headers = header::HeaderMap::new();
-            let mut auth_value = header::HeaderValue::from_static(token);
+
+            // Let it panic if there is no valid value
+            let auth_value = header::HeaderValue::from_str(token.as_str());
+
+            if auth_value.is_err(){
+                panic!("Invalid value given at token");
+            }
+            
+            let mut auth_value = auth_value.unwrap();
+
             auth_value.set_sensitive(true);
             headers.insert(header::AUTHORIZATION, auth_value);
             let new_c = Client::builder().default_headers(headers).build().unwrap();
 
             InteractionHandler {
                 application_id: app_id,
-                app_public_key: app_public_key,
+                app_public_key,
                 client: new_c,
                 global_handles: HashMap::new(),
                 component_handles: HashMap::new(),
@@ -125,7 +142,7 @@ impl InteractionHandler {
         } else {
             InteractionHandler {
                 application_id: app_id,
-                app_public_key: app_public_key,
+                app_public_key,
                 client: Client::new(),
                 global_handles: HashMap::new(),
                 component_handles: HashMap::new(),
@@ -162,7 +179,8 @@ impl InteractionHandler {
     /// async fn pong_handler(ctx: Context) -> InteractionResponse {
     ///     return ctx.respond()
     ///             .content("Pong!")
-    ///             .finish();
+    ///             .build()
+    ///             .unwrap();
     /// }
     ///
     /// #[actix_web::main]
@@ -190,7 +208,7 @@ impl InteractionHandler {
     ///
     /// #[component_handler]
     /// async fn comp_hand(ctx: Context) -> InteractionResponse {
-    ///     return ctx.respond().content("Some message content").finish();
+    ///     return ctx.respond().content("Some message content").build();
     /// }
     ///
     /// #[slash_command]
@@ -208,18 +226,22 @@ impl InteractionHandler {
     ///                            .label("Edit")
     ///                            .custom_id("HEHE")
     ///                            .style(ComponentButtonStyle::Primary)
-    ///                            .finish()
+    ///                            .build()
+    ///                            .unwrap()
     ///        )
     ///        .add_button(
     ///            ComponentButtonBuilder::default()
     ///                            .label("Delete")
     ///                            .custom_id("DELETE")
     ///                            .style(ComponentButtonStyle::Danger)
-    ///                            .finish()
+    ///                            .build()
+    ///                            .unwrap()
     ///         )
-    ///         .finish()
+    ///         .build()
+    ///         .unwrap()
     ///     )
-    ///     .finish();
+    ///     .build()
+    ///     .unwrap();
 
     ///     return resp;
     ///
@@ -236,60 +258,56 @@ impl InteractionHandler {
     pub fn add_component_handle(&mut self, custom_id: &'static str, func: HandlerFunction) {
         self.component_handles.insert(custom_id, func);
     }
-    
 
     #[cfg(feature = "extended-handler")]
     #[cfg_attr(docsrs, doc(cfg(feature = "extended-handler")))]
     /// Register a guild-specific command with Discord!
-    /// 
+    ///
     /// # NOTE
-    /// Guild-specific commands are not cached or saved in any way by the handler. 
+    /// Guild-specific commands are not cached or saved in any way by the handler.
     /// This means that between restarts, updates, crashes, or whatever that causes the app to terminate, the handler 'forgets' which command belonged to which handler.
     pub async fn register_guild_handle(
         &mut self,
         guild: impl Into<Snowflake>,
         cmd: &ApplicationCommand,
         func: HandlerFunction,
-        scope: &ManipulationScope
+        scope: &ManipulationScope,
     ) -> Result<ApplicationCommand, HttpError> {
-        
         let g = guild.into();
-        match scope{
-            ManipulationScope::Local =>{
+        match scope {
+            ManipulationScope::Local => {
                 self.guild_handles.insert(g, func);
                 Ok(cmd.clone())
-            },
-            ManipulationScope::Discord |
-            ManipulationScope::All => {
+            }
+            ManipulationScope::Discord | ManipulationScope::All => {
                 let url = format!(
                     "{}/applications/{}/guilds/{}/commands",
                     crate::BASE_URL,
                     self.application_id,
                     g
                 );
-                
+
                 let r = self.client.post(&url).json(cmd).send().await;
-        
+
                 expect_successful_api_response_and_return!(r, ApplicationCommand, a, {
                     if let Some(id) = a.id {
-
-                        if scope == &ManipulationScope::All{
+                        if scope == &ManipulationScope::All {
                             // Already overwrites current key if it exists, so no need to check.
                             self.guild_handles.insert(id, func);
                         }
-                        
+
                         Ok(a)
                     } else {
                         // Pretty bad if this code reaches...
                         Err(HttpError {
                             code: 0,
-                            message: "Command registration response did not have an ID.".to_string(),
+                            message: "Command registration response did not have an ID."
+                                .to_string(),
                         })
                     }
                 })
-            },
+            }
         }
-        
     }
 
     #[cfg(feature = "extended-handler")]
@@ -301,17 +319,15 @@ impl InteractionHandler {
         id: impl Into<Snowflake>,
         scope: &ManipulationScope,
     ) -> Result<(), HttpError> {
-
         let i = id.into();
         let g = guild.into();
 
-        match scope{
+        match scope {
             ManipulationScope::Local => {
                 self.guild_handles.remove(&i);
                 Ok(())
-            },
-            ManipulationScope::All |
-            ManipulationScope::Discord => {
+            }
+            ManipulationScope::All | ManipulationScope::Discord => {
                 let url = format!(
                     "{}/applications/{}/guilds/{}/commands/{}",
                     crate::BASE_URL,
@@ -319,23 +335,18 @@ impl InteractionHandler {
                     g,
                     i
                 );
-        
+
                 let r = self.client.delete(&url).send().await;
-        
+
                 expect_specific_api_response!(r, StatusCode::NO_CONTENT, {
-                    if scope == &ManipulationScope::All{
+                    if scope == &ManipulationScope::All {
                         self.guild_handles.remove(&i);
                     }
-        
+
                     Ok(())
                 })
-            },
+            }
         }
-
-        
-        
-
-        
     }
 
     /// Entry point function for handling `Interactions`
@@ -421,14 +432,12 @@ impl InteractionHandler {
                             let response = handler(self, ctx).await;
 
                             match_handler_response!(response.r#type, response)
-                            
-                        } 
+                        }
                         // Welp, nothing found. Check for matches in the global map
                         else if let Some(handler) = self
                             .global_handles
                             .get(data.name.as_ref().unwrap().as_str())
                         {
-
                             // construct a Context
                             let ctx = Context::new(self.client.clone(), interaction);
 
@@ -436,14 +445,14 @@ impl InteractionHandler {
                             let response = handler(self, ctx).await;
 
                             match_handler_response!(response.r#type, response)
-                        } 
+                        }
                         // Still nothing, return an error
                         else {
                             error!(
                                 "No associated handler found for {}",
                                 data.name.as_ref().unwrap().as_str()
                             );
-                            ERROR_RESPONSE!(500, "No associated handler found")
+                            ERROR_RESPONSE!(501, "No associated handler found")
                         }
                     }
                     InteractionType::MessageComponent => {
@@ -481,7 +490,7 @@ impl InteractionHandler {
                                 "No associated handler found for {}",
                                 data.custom_id.as_ref().unwrap().as_str()
                             );
-                            ERROR_RESPONSE!(500, "No associated handler found")
+                            ERROR_RESPONSE!(501, "No associated handler found")
                         }
                     }
                 }
