@@ -6,7 +6,7 @@
 //! Note that Discord also has [official documentation](https://discord.com/developers/docs/intro).
 //!
 //! ## Examples
-//! See the [`examples`](https://github.com/hugopilot/rusty-interaction/tree/main/examples`) directory.
+//! See the [`examples`](https://github.com/hugopilot/rusty-interaction/tree/main/examples) directory.
 
 #[macro_use]
 mod macros;
@@ -38,9 +38,15 @@ pub use log;
 #[cfg_attr(docsrs, doc(cfg(feature = "handler")))]
 pub use attributes::*;
 
-#[cfg(all(test, feature = "handler"))]
+#[cfg(all(test, feature = "security"))]
 mod tests;
 
+/// A trait for defining builder patterns.
+pub trait Builder<T>{
+    /// Build the given type
+    fn build(self) -> Result<T, String>;
+}
+
 // ===== USEFUL MACROS =====
 #[macro_export]
 #[doc(hidden)]
@@ -123,8 +129,7 @@ macro_rules! expect_successful_api_response_and_return {
                         message: e,
                     })
                 } else {
-                    let a: Result<$struc, serde_json::Error> =
-                        serde_json::from_str(&text);
+                    let a: Result<$struc, serde_json::Error> = serde_json::from_str(&text);
 
                     match a {
                         Err(e) => {
