@@ -234,7 +234,8 @@ impl InteractionResponseBuilder {
     }
 
     /// Add components to response
-    pub fn add_component_row(mut self, component: &MessageComponent) -> Self {
+    pub fn add_component_row(mut self, comp: impl Into<MessageComponent>) -> Self {
+        let component = comp.into();
         match self.data.as_mut() {
             None => {
                 let mut d = InteractionApplicationCommandCallbackData::new();
@@ -607,7 +608,7 @@ impl Context {
             b.r#type = InteractionResponseType::UpdateMessage;
         }
 
-        return b;
+        b
     }
 
     /// Edit the original interaction response
